OSG Python Tools
======================

The Operating System Group: https://osg.tuhh.de

This repository has multiple targets. It is

1. An opinionated selection of Python packages that we want to use for
   managing our experiments and data.

2. An collection of small functions that we use for looking at said
   data.

Installation
------------

## Just install without local checkout and code editing possibility
     pip3 install git+https://github.com/tuhhosg/osgpy

## With local code checkout and code changes have immediate effects
	git clone git@github.com:tuhhosg/osgpy.git
	cd osgpy
	pip3 install -e .
